@@ -26,6 +26,7 @@ from schemathesis.engine import Status, events
 from schemathesis.engine.phases import PhaseName, PhaseSkipReason
 from schemathesis.engine.phases.probes import ProbeOutcome
 from schemathesis.engine.recorder import Interaction, ScenarioRecorder
+from schemathesis.generation.meta import CoveragePhaseData
 from schemathesis.generation.modes import GenerationMode
 from schemathesis.schemas import ApiStatistic
 
@@ -591,6 +592,7 @@ class StatefulProgressManager:
     console: Console
     title: str
     links_selected: int
+    links_inferred: int
     links_total: int
     start_time: float
 
@@ -615,6 +617,7 @@ class StatefulProgressManager:
         "console",
         "title",
         "links_selected",
+        "links_inferred",
         "links_total",
         "start_time",
         "title_progress",
@@ -630,13 +633,16 @@ class StatefulProgressManager:
         "is_interrupted",
     )
 
-    def __init__(self, *, console: Console, title: str, links_selected: int, links_total: int) -> None:
+    def __init__(
+        self, *, console: Console, title: str, links_selected: int, links_inferred: int, links_total: int
+    ) -> None:
         from rich.progress import Progress, SpinnerColumn, TextColumn, TimeElapsedColumn
         from rich.style import Style
 
         self.console = console
         self.title = title
         self.links_selected = links_selected
+        self.links_inferred = links_inferred
         self.links_total = links_total
         self.start_time = time.monotonic()
 
@@ -685,9 +691,10 @@ class StatefulProgressManager:
 
         # Initialize progress displays
         self.title_task_id = self.title_progress.add_task("Stateful")
-        self.progress_task_id = self.progress_bar.add_task(
-            "", scenarios=0, links=f"0 covered / {self.links_selected} selected / {self.links_total} total links"
-        )
+        links = f"0 covered / {self.links_selected} selected / {self.links_total} total"
+        if self.links_inferred:
+            links += f" ({self.links_inferred} inferred)"
+        self.progress_task_id = self.progress_bar.add_task("", scenarios=0, links=links)
 
         # Create live display
         group = Group(
@@ -719,11 +726,10 @@ class StatefulProgressManager:
     def _update_progress_display(self) -> None:
         """Update the progress display."""
         assert self.progress_task_id is not None
-        self.progress_bar.update(
-            self.progress_task_id,
-            scenarios=self.scenarios,
-            links=f"{len(self.links_covered)} covered / {self.links_selected} selected / {self.links_total} total links",
-        )
+        links = f"{len(self.links_covered)} covered / {self.links_selected} selected / {self.links_total} total"
+        if self.links_inferred:
+            links += f" ({self.links_inferred} inferred)"
+        self.progress_bar.update(self.progress_task_id, scenarios=self.scenarios, links=links)
 
     def _get_stats_message(self) -> str:
         """Get formatted stats message."""
@@ -887,7 +893,7 @@ class OutputHandler(EventHandler):
         elif phase.name in [PhaseName.EXAMPLES, PhaseName.COVERAGE, PhaseName.FUZZING] and phase.is_enabled:
             self._start_unit_tests(phase.name)
         elif phase.name == PhaseName.STATEFUL_TESTING and phase.is_enabled and phase.skip_reason is None:
-            self._start_stateful_tests()
+            self._start_stateful_tests(event)
 
     def _start_probing(self) -> None:
         self.probing_manager = ProbingProgressManager(console=self.console)
@@ -903,13 +909,18 @@ class OutputHandler(EventHandler):
         )
         self.unit_tests_manager.start()
 
-    def _start_stateful_tests(self) -> None:
+    def _start_stateful_tests(self, event: events.PhaseStarted) -> None:
         assert self.statistic is not None
+        assert event.payload is not None
+        # Total number of links - original ones + inferred during tests
+        links_selected = self.statistic.links.selected + event.payload.inferred_links
+        links_total = self.statistic.links.total + event.payload.inferred_links
         self.stateful_tests_manager = StatefulProgressManager(
             console=self.console,
             title="Stateful",
-            links_selected=self.statistic.links.selected,
-            links_total=self.statistic.links.total,
+            links_selected=links_selected,
+            links_inferred=event.payload.inferred_links,
+            links_total=links_total,
         )
         self.stateful_tests_manager.start()
 
@@ -989,10 +1000,10 @@ class OutputHandler(EventHandler):
             table.add_column("Field", style=Style(color="bright_white", bold=True))
             table.add_column("Value", style="cyan")
             table.add_row("Scenarios:", f"{self.stateful_tests_manager.scenarios}")
-            table.add_row(
-                "API Links:",
-                f"{len(self.stateful_tests_manager.links_covered)} covered / {self.stateful_tests_manager.links_selected} selected / {self.stateful_tests_manager.links_total} total",
-            )
+            message = f"{len(self.stateful_tests_manager.links_covered)} covered / {self.stateful_tests_manager.links_selected} selected / {self.stateful_tests_manager.links_total} total"
+            if self.stateful_tests_manager.links_inferred:
+                message += f" ({self.stateful_tests_manager.links_inferred} inferred)"
+            table.add_row("API Links:", message)
 
             self.console.print()
             self.console.print(Padding(table, BLOCK_PADDING))
@@ -1053,10 +1064,19 @@ class OutputHandler(EventHandler):
 
         warnings = self.config.warnings_for(operation=operation)
 
+        def has_only_missing_auth_case() -> bool:
+            case = list(event.recorder.cases.values())[0].value
+            return bool(
+                case.meta
+                and isinstance(case.meta.phase.data, CoveragePhaseData)
+                and case.meta.phase.data.description == "Missing `Authorization` at header"
+            )
+
         if SchemathesisWarning.MISSING_AUTH in warnings:
-            for status_code in (401, 403):
-                if statistic.ratio_for(status_code) >= AUTH_ERRORS_THRESHOLD:
-                    self.warnings.missing_auth.setdefault(status_code, set()).add(event.recorder.label)
+            if not (len(event.recorder.cases) == 1 and has_only_missing_auth_case()):
+                for status_code in (401, 403):
+                    if statistic.ratio_for(status_code) >= AUTH_ERRORS_THRESHOLD:
+                        self.warnings.missing_auth.setdefault(status_code, set()).add(event.recorder.label)
 
         # Warn if all positive test cases got 4xx in return and no failure was found
         def all_positive_are_rejected(recorder: ScenarioRecorder) -> bool:
@@ -1220,10 +1240,10 @@ class OutputHandler(EventHandler):
         click.echo()
         if self.warnings.missing_auth:
             self._display_warning_block(
-                title="Missing authentication",
+                title="Authentication failed",
                 operations=self.warnings.missing_auth,
                 operation_suffix=" returned authentication errors",
-                tips=["💡 Use --auth or -H to provide authentication credentials"],
+                tips=["💡 Ensure valid authentication credentials are set via --auth or -H"],
             )
 
         if self.warnings.missing_test_data:
