@@ -6,7 +6,18 @@ from contextlib import contextmanager, suppress
 from dataclasses import dataclass
 from functools import lru_cache, partial
 from itertools import combinations
-from json.encoder import _make_iterencode, c_make_encoder, encode_basestring_ascii  # type: ignore
+
+try:
+    from json.encoder import _make_iterencode  # type: ignore[attr-defined]
+except ImportError:
+    _make_iterencode = None
+
+try:
+    from json.encoder import c_make_encoder  # type: ignore[attr-defined]
+except ImportError:
+    c_make_encoder = None
+
+from json.encoder import JSONEncoder, encode_basestring_ascii  # type: ignore
 from typing import Any, Callable, Generator, Iterator, TypeVar, cast
 from urllib.parse import quote_plus
 
@@ -233,6 +244,9 @@ class CoverageContext:
             return cached_draw(st.integers(min_value=schema.get("minimum"), max_value=schema.get("maximum")))
         if "enum" in schema:
             return cached_draw(st.sampled_from(schema["enum"]))
+        if keys == ["multipleOf", "type"] and schema["type"] in ("integer", "number"):
+            step = schema["multipleOf"]
+            return cached_draw(st.integers().map(step.__mul__))
         if "pattern" in schema:
             pattern = schema["pattern"]
             try:
@@ -282,10 +296,13 @@ T = TypeVar("T")
 
 if c_make_encoder is not None:
     _iterencode = c_make_encoder(None, None, encode_basestring_ascii, None, ":", ",", True, False, False)
-else:
+elif _make_iterencode is not None:
     _iterencode = _make_iterencode(
         None, None, encode_basestring_ascii, None, float.__repr__, ":", ",", True, False, True
     )
+else:
+    encoder = JSONEncoder(skipkeys=False, sort_keys=False, indent=None, separators=(":", ","))
+    _iterencode = encoder.iterencode
 
 
 def _encode(o: Any) -> str:
@@ -318,7 +335,7 @@ class HashSet:
 
 
 def _cover_positive_for_type(
-    ctx: CoverageContext, schema: dict, ty: str | None
+    ctx: CoverageContext, schema: dict, ty: str | None, seen: HashSet | None = None
 ) -> Generator[GeneratedValue, None, None]:
     if ty == "object" or ty == "array":
         template_schema = _get_template_schema(schema, ty)
@@ -366,6 +383,9 @@ def _cover_positive_for_type(
                 yield from _positive_object(ctx, schema, cast(dict, template))
         elif "properties" in schema or "required" in schema:
             yield from _positive_object(ctx, schema, cast(dict, template))
+        elif "not" in schema and isinstance(schema["not"], (dict, bool)):
+            nctx = ctx.with_negative()
+            yield from cover_schema_iter(nctx, schema["not"], seen)
 
 
 @contextmanager
@@ -394,9 +414,12 @@ def cover_schema_iter(
 ) -> Generator[GeneratedValue, None, None]:
     if seen is None:
         seen = HashSet()
-    if isinstance(schema, bool):
+    if schema == {} or schema is True:
         types = ["null", "boolean", "string", "number", "array", "object"]
         schema = {}
+    elif schema is False:
+        types = []
+        schema = {"not": {}}
     else:
         types = schema.get("type", [])
     push_examples_to_properties(schema)
@@ -594,12 +617,52 @@ def cover_schema_iter(
                         with _ignore_unfixable():
                             canonical = canonicalish(schema)
                             yield from cover_schema_iter(nctx, canonical, seen)
-                elif key == "anyOf" or key == "oneOf":
+                elif key == "anyOf":
                     nctx = ctx.with_negative()
-                    # NOTE: Other sub-schemas are not filtered out
+                    validators = [jsonschema.validators.validator_for(sub_schema)(sub_schema) for sub_schema in value]
                     for idx, sub_schema in enumerate(value):
                         with nctx.at(idx):
-                            yield from cover_schema_iter(nctx, sub_schema, seen)
+                            for value in cover_schema_iter(nctx, sub_schema, seen):
+                                # Negative value for this schema could be a positive value for another one
+                                if is_valid_for_others(value.value, idx, validators):
+                                    continue
+                                yield value
+                elif key == "oneOf":
+                    nctx = ctx.with_negative()
+                    validators = [jsonschema.validators.validator_for(sub_schema)(sub_schema) for sub_schema in value]
+                    for idx, sub_schema in enumerate(value):
+                        with nctx.at(idx):
+                            for value in cover_schema_iter(nctx, sub_schema, seen):
+                                if is_invalid_for_oneOf(value.value, idx, validators):
+                                    yield value
+                elif key == "not" and isinstance(value, (dict, bool)):
+                    pctx = ctx.with_positive()
+                    yield from cover_schema_iter(pctx, value, seen)
+
+
+def is_valid_for_others(value: Any, idx: int, validators: list[jsonschema.Validator]) -> bool:
+    for vidx, validator in enumerate(validators):
+        if idx == vidx:
+            # This one is being negated
+            continue
+        if validator.is_valid(value):
+            return True
+    return False
+
+
+def is_invalid_for_oneOf(value: Any, idx: int, validators: list[jsonschema.Validator]) -> bool:
+    valid_count = 0
+    for vidx, validator in enumerate(validators):
+        if idx == vidx:
+            # This one is being negated
+            continue
+        if validator.is_valid(value):
+            valid_count += 1
+            # Should circuit - no need to validate more, it is already invalid
+            if valid_count > 1:
+                return True
+    # No matching at all - we successfully generated invalid value
+    return valid_count == 0
 
 
 def _get_properties(schema: dict | bool) -> dict | bool:
@@ -650,6 +713,7 @@ def _ensure_valid_headers_schema(schema: dict[str, Any]) -> dict[str, Any]:
 def _positive_string(ctx: CoverageContext, schema: dict) -> Generator[GeneratedValue, None, None]:
     """Generate positive string values."""
     # Boundary and near boundary values
+    schema = {"type": "string", **schema}
     min_length = schema.get("minLength")
     if min_length == 0:
         min_length = None
@@ -751,6 +815,7 @@ def closest_multiple_greater_than(y: int, x: int) -> int:
 def _positive_number(ctx: CoverageContext, schema: dict) -> Generator[GeneratedValue, None, None]:
     """Generate positive integer values."""
     # Boundary and near boundary values
+    schema = {"type": "number", **schema}
     minimum = schema.get("minimum")
     maximum = schema.get("maximum")
     exclusive_minimum = schema.get("exclusiveMinimum")
