@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import asyncio
+import warnings
 from dataclasses import dataclass
 from enum import Enum
 from functools import wraps
@@ -19,14 +20,15 @@ from requests.models import CaseInsensitiveDict
 from schemathesis import auths
 from schemathesis.auths import AuthStorage, AuthStorageMark
 from schemathesis.config import GenerationConfig, ProjectConfig
-from schemathesis.core import NOT_SET, NotSet, SpecificationFeature, media_types
+from schemathesis.core import INJECTED_PATH_PARAMETER_KEY, NOT_SET, NotSet, SpecificationFeature, media_types
 from schemathesis.core.errors import InvalidSchema, SerializationNotPossible
 from schemathesis.core.marks import Mark
+from schemathesis.core.transforms import deepclone
 from schemathesis.core.transport import prepare_urlencoded
 from schemathesis.core.validation import has_invalid_characters, is_latin_1_encodable
 from schemathesis.generation import GenerationMode, coverage
 from schemathesis.generation.case import Case
-from schemathesis.generation.hypothesis import DEFAULT_DEADLINE, examples, setup, strategies
+from schemathesis.generation.hypothesis import examples, setup, strategies
 from schemathesis.generation.hypothesis.examples import add_single_example
 from schemathesis.generation.hypothesis.given import GivenInput
 from schemathesis.generation.meta import (
@@ -122,9 +124,6 @@ def create_test(
     settings = getattr(hypothesis_test, SETTINGS_ATTRIBUTE_NAME, None)
     assert settings is not None
 
-    if settings.deadline == default.deadline:
-        settings = hypothesis.settings(settings, deadline=DEFAULT_DEADLINE)
-
     if settings.verbosity == default.verbosity:
         settings = hypothesis.settings(settings, verbosity=Verbosity.quiet)
 
@@ -186,6 +185,18 @@ def create_test(
             generation_config=generation,
         )
 
+    injected_path_parameter_names = [
+        parameter.name
+        for parameter in operation.path_parameters
+        if parameter.definition.get(INJECTED_PATH_PARAMETER_KEY)
+    ]
+    if injected_path_parameter_names:
+        names = ", ".join(f"'{name}'" for name in injected_path_parameter_names)
+        plural = "s" if len(injected_path_parameter_names) > 1 else ""
+        verb = "are" if len(injected_path_parameter_names) > 1 else "is"
+        error = InvalidSchema(f"Path parameter{plural} {names} {verb} not defined")
+        MissingPathParameters.set(hypothesis_test, error)
+
     setattr(hypothesis_test, SETTINGS_ATTRIBUTE_NAME, settings)
 
     return hypothesis_test
@@ -235,6 +246,22 @@ def add_examples(
     hook_dispatcher: HookDispatcher | None = None,
     **kwargs: Any,
 ) -> Callable:
+    for example in generate_example_cases(
+        test=test, operation=operation, fill_missing=fill_missing, hook_dispatcher=hook_dispatcher, **kwargs
+    ):
+        test = hypothesis.example(case=example)(test)
+
+    return test
+
+
+def generate_example_cases(
+    *,
+    test: Callable,
+    operation: APIOperation,
+    fill_missing: bool,
+    hook_dispatcher: HookDispatcher | None = None,
+    **kwargs: Any,
+) -> Generator[Case]:
     """Add examples to the Hypothesis test, if they are specified in the schema."""
     from hypothesis_jsonschema._canonicalise import HypothesisRefResolutionError
 
@@ -274,9 +301,7 @@ def add_examples(
                 InvalidHeadersExampleMark.set(original_test, invalid_headers)
                 continue
         adjust_urlencoded_payload(example)
-        test = hypothesis.example(case=example)(test)
-
-    return test
+        yield example
 
 
 def adjust_urlencoded_payload(case: Case) -> None:
@@ -299,6 +324,29 @@ def add_coverage(
     unexpected_methods: set[str],
     generation_config: GenerationConfig,
 ) -> Callable:
+    for case in generate_coverage_cases(
+        operation=operation,
+        generation_modes=generation_modes,
+        auth_storage=auth_storage,
+        as_strategy_kwargs=as_strategy_kwargs,
+        generate_duplicate_query_parameters=generate_duplicate_query_parameters,
+        unexpected_methods=unexpected_methods,
+        generation_config=generation_config,
+    ):
+        test = hypothesis.example(case=case)(test)
+    return test
+
+
+def generate_coverage_cases(
+    *,
+    operation: APIOperation,
+    generation_modes: list[GenerationMode],
+    auth_storage: AuthStorage | None,
+    as_strategy_kwargs: dict[str, Any],
+    generate_duplicate_query_parameters: bool,
+    unexpected_methods: set[str],
+    generation_config: GenerationConfig,
+) -> Generator[Case]:
     from schemathesis.specs.openapi.constants import LOCATION_TO_CONTAINER
 
     auth_context = auths.AuthContext(
@@ -310,26 +358,28 @@ def add_coverage(
         for container in LOCATION_TO_CONTAINER.values()
         if container in as_strategy_kwargs
     }
-    for case in _iter_coverage_cases(
-        operation=operation,
-        generation_modes=generation_modes,
-        generate_duplicate_query_parameters=generate_duplicate_query_parameters,
-        unexpected_methods=unexpected_methods,
-        generation_config=generation_config,
-    ):
-        if case.media_type and operation.schema.transport.get_first_matching_media_type(case.media_type) is None:
-            continue
-        adjust_urlencoded_payload(case)
-        auths.set_on_case(case, auth_context, auth_storage)
-        for container_name, value in overrides.items():
-            container = getattr(case, container_name)
-            if container is None:
-                setattr(case, container_name, value)
-            else:
-                container.update(value)
-
-        test = hypothesis.example(case=case)(test)
-    return test
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=".*but this is not valid syntax for a Python regular expression.*", category=UserWarning
+        )
+        for case in _iter_coverage_cases(
+            operation=operation,
+            generation_modes=generation_modes,
+            generate_duplicate_query_parameters=generate_duplicate_query_parameters,
+            unexpected_methods=unexpected_methods,
+            generation_config=generation_config,
+        ):
+            if case.media_type and operation.schema.transport.get_first_matching_media_type(case.media_type) is None:
+                continue
+            adjust_urlencoded_payload(case)
+            auths.set_on_case(case, auth_context, auth_storage)
+            for container_name, value in overrides.items():
+                container = getattr(case, container_name)
+                if container is None:
+                    setattr(case, container_name, value)
+                else:
+                    container.update(value)
+            yield case
 
 
 class Instant:
@@ -397,7 +447,7 @@ class Template:
         return output
 
     def unmodified(self) -> TemplateValue:
-        kwargs = self._template.copy()
+        kwargs = deepclone(self._template)
         kwargs = self._serialize(kwargs)
         return TemplateValue(kwargs=kwargs, components=self._components.copy())
 
@@ -864,3 +914,4 @@ UnsatisfiableExampleMark = Mark[Unsatisfiable](attr_name="unsatisfiable_example"
 NonSerializableMark = Mark[SerializationNotPossible](attr_name="non_serializable")
 InvalidRegexMark = Mark[SchemaError](attr_name="invalid_regex")
 InvalidHeadersExampleMark = Mark[dict[str, str]](attr_name="invalid_example_header")
+MissingPathParameters = Mark[InvalidSchema](attr_name="missing_path_parameters")
