@@ -2,10 +2,11 @@ from __future__ import annotations
 
 import inspect
 from collections import defaultdict
+from contextlib import contextmanager
 from dataclasses import dataclass, field
 from enum import Enum, unique
-from functools import partial
-from typing import TYPE_CHECKING, Any, Callable, ClassVar, cast
+from functools import lru_cache, partial
+from typing import TYPE_CHECKING, Any, Callable, ClassVar, Generator, cast
 
 from schemathesis.core.marks import Mark
 from schemathesis.core.transport import Response
@@ -54,18 +55,28 @@ def to_filterable_hook(dispatcher: HookDispatcher) -> Callable:
     filter_used = False
     filter_set = FilterSet()
 
+    @contextmanager
+    def _reset_on_error() -> Generator:
+        try:
+            yield
+        except Exception:
+            filter_set.clear()
+            raise
+
     def register(hook: str | Callable) -> Callable:
         nonlocal filter_set
 
         if filter_used:
-            validate_filterable_hook(hook)
+            with _reset_on_error():
+                validate_filterable_hook(hook)
 
         if isinstance(hook, str):
 
             def decorator(func: Callable) -> Callable:
                 hook_name = cast(str, hook)
                 if filter_used:
-                    validate_filterable_hook(hook)
+                    with _reset_on_error():
+                        validate_filterable_hook(hook)
                 func.filter_set = filter_set  # type: ignore[attr-defined]
                 return dispatcher.register_hook_with_name(func, hook_name)
 
@@ -86,13 +97,15 @@ def to_filterable_hook(dispatcher: HookDispatcher) -> Callable:
             nonlocal filter_used
 
             filter_used = True
-            filter_set.include(*args, **kwargs)
+            with _reset_on_error():
+                filter_set.include(*args, **kwargs)
 
         def exclude(*args: Any, **kwargs: Any) -> None:
             nonlocal filter_used
 
             filter_used = True
-            filter_set.exclude(*args, **kwargs)
+            with _reset_on_error():
+                filter_set.exclude(*args, **kwargs)
 
         attach_filter_chain(target, "apply_to", include)
         attach_filter_chain(target, "skip_for", exclude)
@@ -113,11 +126,9 @@ class HookDispatcher:
     _hooks: defaultdict[str, list[Callable]] = field(default_factory=lambda: defaultdict(list))
     _specs: ClassVar[dict[str, RegisteredHook]] = {}
 
-    def __post_init__(self) -> None:
-        self.hook = to_filterable_hook(self)  # type: ignore[method-assign]
-
-    def hook(self, hook: str | Callable) -> Callable:
-        raise NotImplementedError
+    @property
+    def hook(self) -> Callable:
+        return to_filterable_hook(self)
 
     def apply(self, hook: Callable, *, name: str | None = None) -> Callable[[Callable], Callable]:
         """Register hook to run only on one test function.
@@ -201,6 +212,9 @@ class HookDispatcher:
         """Get a list of hooks registered for a name."""
         return self._hooks.get(name, [])
 
+    def get_all(self) -> dict[str, list[Callable]]:
+        return self._hooks
+
     def apply_to_container(
         self, strategy: st.SearchStrategy, container: str, context: HookContext
     ) -> st.SearchStrategy:
@@ -225,12 +239,18 @@ class HookDispatcher:
             strategy = strategy.flatmap(hook)
         return strategy
 
-    def dispatch(self, name: str, context: HookContext, *args: Any, **kwargs: Any) -> None:
+    def dispatch(
+        self, name: str, context: HookContext, *args: Any, _with_dual_style_kwargs: bool = False, **kwargs: Any
+    ) -> None:
         """Run all hooks for the given name."""
         for hook in self.get_all_by_name(name):
             if _should_skip_hook(hook, context):
                 continue
-            hook(context, *args, **kwargs)
+            # NOTE: It is a backward-compat shim to support calling `before_call` with `**kwargs` OR with `kwargs`.
+            if _with_dual_style_kwargs and not has_var_keyword(hook):
+                hook(context, *args, kwargs)
+            else:
+                hook(context, *args, **kwargs)
 
     def unregister(self, hook: Callable) -> None:
         """Unregister a specific hook."""
@@ -246,6 +266,12 @@ class HookDispatcher:
         self._hooks = defaultdict(list)
 
 
+@lru_cache(maxsize=16)
+def has_var_keyword(hook: Callable) -> bool:
+    """Check if hook function accepts **kwargs."""
+    return any(p.kind == inspect.Parameter.VAR_KEYWORD for p in inspect.signature(hook).parameters.values())
+
+
 def _should_skip_hook(hook: Callable, ctx: HookContext) -> bool:
     filter_set = getattr(hook, "filter_set", None)
     return filter_set is not None and ctx.operation is not None and not filter_set.match(ctx)
@@ -349,7 +375,7 @@ def before_init_operation(context: HookContext, operation: APIOperation) -> None
 
 
 @HookDispatcher.register_spec([HookScope.GLOBAL])
-def before_call(context: HookContext, case: Case, **kwargs: Any) -> None:
+def before_call(context: HookContext, case: Case, kwargs: dict[str, Any]) -> None:
     """Called before every network call in CLI tests.
 
     Use cases:
@@ -395,7 +421,7 @@ def hook(hook: str | Callable) -> Callable:
                 return query and "user_id" in query
 
             @schemathesis.hook
-            def before_call(ctx, case):
+            def before_call(ctx, case, **kwargs):
                 \"\"\"Modify headers before sending each request\"\"\"
                 if case.headers is None:
                     case.headers = {}
