@@ -27,7 +27,7 @@ from schemathesis.generation.case import Case
 from schemathesis.generation.hypothesis import strategies
 from schemathesis.generation.hypothesis.given import GivenInput, given_proxy
 from schemathesis.generation.meta import CaseMetadata
-from schemathesis.hooks import HookDispatcherMark
+from schemathesis.hooks import HookDispatcherMark, _should_skip_hook
 
 from .auths import AuthStorage
 from .filters import (
@@ -545,10 +545,6 @@ class Parameter:
         """Whether the parameter is required for a successful API call."""
         raise NotImplementedError
 
-    def serialize(self, operation: APIOperation) -> str:
-        """Get parameter's string representation."""
-        raise NotImplementedError
-
 
 P = TypeVar("P", bound=Parameter)
 
@@ -620,7 +616,7 @@ class OperationDefinition(Generic[D]):
     def _repr_pretty_(self, *args: Any, **kwargs: Any) -> None: ...
 
 
-@dataclass(eq=False)
+@dataclass()
 class APIOperation(Generic[P]):
     """An API operation (e.g., `GET /users`)."""
 
@@ -647,6 +643,14 @@ class APIOperation(Generic[P]):
     def __deepcopy__(self, memo: dict) -> APIOperation[P]:
         return self
 
+    def __hash__(self) -> int:
+        return hash(self.label)
+
+    def __eq__(self, value: object, /) -> bool:
+        if not isinstance(value, APIOperation):
+            return NotImplemented
+        return self.label == value.label
+
     @property
     def full_path(self) -> str:
         return self.schema.get_full_path(self.path)
@@ -700,19 +704,30 @@ class APIOperation(Generic[P]):
             **kwargs: Extra arguments to the underlying strategy function.
 
         """
+        if self.schema.config.headers:
+            headers = kwargs.setdefault("headers", {})
+            headers.update(self.schema.config.headers)
         strategy = self.schema.get_case_strategy(self, generation_mode=generation_mode, **kwargs)
 
         def _apply_hooks(dispatcher: HookDispatcher, _strategy: SearchStrategy[Case]) -> SearchStrategy[Case]:
             context = HookContext(operation=self)
             for hook in dispatcher.get_all_by_name("before_generate_case"):
+                if _should_skip_hook(hook, context):
+                    continue
                 _strategy = hook(context, _strategy)
             for hook in dispatcher.get_all_by_name("filter_case"):
+                if _should_skip_hook(hook, context):
+                    continue
                 hook = partial(hook, context)
                 _strategy = _strategy.filter(hook)
             for hook in dispatcher.get_all_by_name("map_case"):
+                if _should_skip_hook(hook, context):
+                    continue
                 hook = partial(hook, context)
                 _strategy = _strategy.map(hook)
             for hook in dispatcher.get_all_by_name("flatmap_case"):
+                if _should_skip_hook(hook, context):
+                    continue
                 hook = partial(hook, context)
                 _strategy = _strategy.flatmap(hook)
             return _strategy
