@@ -5,7 +5,6 @@ from contextlib import suppress
 from dataclasses import dataclass
 from typing import Any, Callable, Dict, Iterable, Optional, Union, cast
 from urllib.parse import quote_plus
-from weakref import WeakKeyDictionary
 
 import jsonschema.protocols
 from hypothesis import event, note, reject
@@ -23,10 +22,11 @@ from schemathesis.generation.meta import (
     CaseMetadata,
     ComponentInfo,
     ComponentKind,
-    ExplicitPhaseData,
-    GeneratePhaseData,
+    ExamplesPhaseData,
+    FuzzingPhaseData,
     GenerationInfo,
     PhaseInfo,
+    StatefulPhaseData,
     TestPhase,
 )
 from schemathesis.openapi.generation.filters import is_valid_header, is_valid_path, is_valid_query, is_valid_urlencoded
@@ -36,7 +36,13 @@ from ... import auths
 from ...generation import GenerationMode
 from ...hooks import HookContext, HookDispatcher, apply_to_all_dispatchers
 from .constants import LOCATION_TO_CONTAINER
-from .formats import HEADER_FORMAT, STRING_FORMATS, get_default_format_strategies, header_values
+from .formats import (
+    DEFAULT_HEADER_EXCLUDE_CHARACTERS,
+    HEADER_FORMAT,
+    STRING_FORMATS,
+    get_default_format_strategies,
+    header_values,
+)
 from .media_types import MEDIA_TYPES
 from .negative import negative_schema
 from .negative.utils import can_negate
@@ -64,7 +70,6 @@ def openapi_cases(
     body: Any = NOT_SET,
     media_type: str | None = None,
     phase: TestPhase = TestPhase.FUZZING,
-    __is_stateful_phase: bool = False,
 ) -> Any:
     """A strategy that creates `Case` instances.
 
@@ -81,8 +86,7 @@ def openapi_cases(
     start = time.monotonic()
     strategy_factory = GENERATOR_MODE_TO_STRATEGY_FACTORY[generation_mode]
 
-    phase_name = "stateful" if __is_stateful_phase else phase.value
-    generation_config = operation.schema.config.generation_for(operation=operation, phase=phase_name)
+    generation_config = operation.schema.config.generation_for(operation=operation, phase=phase.value)
 
     ctx = HookContext(operation=operation)
 
@@ -151,10 +155,11 @@ def openapi_cases(
             reject()
 
     _phase_data = {
-        TestPhase.EXAMPLES: ExplicitPhaseData(),
-        TestPhase.FUZZING: GeneratePhaseData(),
+        TestPhase.EXAMPLES: ExamplesPhaseData(),
+        TestPhase.FUZZING: FuzzingPhaseData(),
+        TestPhase.STATEFUL: StatefulPhaseData(),
     }[phase]
-    phase_data = cast(Union[ExplicitPhaseData, GeneratePhaseData], _phase_data)
+    phase_data = cast(Union[ExamplesPhaseData, FuzzingPhaseData, StatefulPhaseData], _phase_data)
 
     instance = operation.Case(
         media_type=media_type,
@@ -190,9 +195,6 @@ def openapi_cases(
     return instance
 
 
-_BODY_STRATEGIES_CACHE: WeakKeyDictionary = WeakKeyDictionary()
-
-
 def _get_body_strategy(
     parameter: OpenAPIBody,
     strategy_factory: StrategyFactory,
@@ -203,10 +205,6 @@ def _get_body_strategy(
 
     if parameter.media_type in MEDIA_TYPES:
         return MEDIA_TYPES[parameter.media_type]
-    # The cache key relies on object ids, which means that the parameter should not be mutated
-    # Note, the parent schema is not included as each parameter belong only to one schema
-    if parameter in _BODY_STRATEGIES_CACHE and strategy_factory in _BODY_STRATEGIES_CACHE[parameter]:
-        return _BODY_STRATEGIES_CACHE[parameter][strategy_factory]
     schema = parameter.as_json_schema(operation)
     schema = operation.schema.prepare_schema(schema)
     assert isinstance(operation.schema, BaseOpenAPISchema)
@@ -215,7 +213,6 @@ def _get_body_strategy(
     )
     if not parameter.is_required:
         strategy |= st.just(NOT_SET)
-    _BODY_STRATEGIES_CACHE.setdefault(parameter, {})[strategy_factory] = strategy
     return strategy
 
 
@@ -248,9 +245,6 @@ def get_parameters_value(
     return value
 
 
-_PARAMETER_STRATEGIES_CACHE: WeakKeyDictionary = WeakKeyDictionary()
-
-
 @dataclass
 class ValueContainer:
     """Container for a value generated by a data generator or explicitly provided."""
@@ -301,6 +295,8 @@ def generate_parameter(
     if value == explicit:
         # When we pass `explicit`, then its parts are excluded from generation of the final value
         # If the final value is the same, then other parameters were generated at all
+        if value is not None and location == "path":
+            value = quote_all(value)
         used_generator = None
     return ValueContainer(value=value, location=location, generator=used_generator)
 
@@ -350,10 +346,6 @@ def get_parameters_strategy(
 
     parameters = getattr(operation, LOCATION_TO_CONTAINER[location])
     if parameters:
-        # The cache key relies on object ids, which means that the parameter should not be mutated
-        nested_cache_key = (strategy_factory, location, tuple(sorted(exclude)))
-        if operation in _PARAMETER_STRATEGIES_CACHE and nested_cache_key in _PARAMETER_STRATEGIES_CACHE[operation]:
-            return _PARAMETER_STRATEGIES_CACHE[operation][nested_cache_key]
         schema = get_schema_for_location(operation, location, parameters)
         if location == "header" and exclude:
             # Remove excluded headers case-insensitively
@@ -397,7 +389,6 @@ def get_parameters_strategy(
                 strategy = strategy.map(quote_all).map(jsonify_python_specific_types)
             elif location == "query":
                 strategy = strategy.map(jsonify_python_specific_types)
-        _PARAMETER_STRATEGIES_CACHE.setdefault(operation, {})[nested_cache_key] = strategy
         return strategy
     # No parameters defined for this location
     return st.none()
@@ -425,10 +416,17 @@ def jsonify_python_specific_types(value: dict[str, Any]) -> dict[str, Any]:
 
 def _build_custom_formats(generation_config: GenerationConfig) -> dict[str, st.SearchStrategy]:
     custom_formats = {**get_default_format_strategies(), **STRING_FORMATS}
+    header_values_kwargs = {}
     if generation_config.exclude_header_characters is not None:
-        custom_formats[HEADER_FORMAT] = header_values(exclude_characters=generation_config.exclude_header_characters)
+        header_values_kwargs["exclude_characters"] = generation_config.exclude_header_characters
+        if not generation_config.allow_x00:
+            header_values_kwargs["exclude_characters"] += "\x00"
     elif not generation_config.allow_x00:
-        custom_formats[HEADER_FORMAT] = header_values(exclude_characters="\n\r\x00")
+        header_values_kwargs["exclude_characters"] = DEFAULT_HEADER_EXCLUDE_CHARACTERS + "\x00"
+    if generation_config.codec is not None:
+        header_values_kwargs["codec"] = generation_config.codec
+    if header_values_kwargs:
+        custom_formats[HEADER_FORMAT] = header_values(**header_values_kwargs)
     return custom_formats
 
 
