@@ -366,7 +366,10 @@ def use_after_free(ctx: CheckContext, response: Response, case: Case) -> bool |
 
     if not isinstance(case.operation.schema, BaseOpenAPISchema) or is_unexpected_http_status_case(case):
         return True
-    if response.status_code == 404 or response.status_code >= 500:
+
+    # Only check for use-after-free on successful responses (2xx) or redirects (3xx)
+    # Other status codes indicate request-level issues / server errors, not successful resource access
+    if not (200 <= response.status_code < 400):
         return None
 
     for related_case in ctx._find_related(case_id=case.id):
@@ -408,8 +411,11 @@ def ensure_resource_availability(ctx: CheckContext, response: Response, case: Ca
     if not isinstance(case.operation.schema, BaseOpenAPISchema) or is_unexpected_http_status_case(case):
         return True
 
-    # First, check if this is a 4XX response
-    if not (400 <= response.status_code < 500):
+    # Only check for 404 (Not Found) responses - other 4XX are not resource availability issues
+    # 422 / 400: Validation errors (bad request data)
+    # 401 / 403: Auth issues (expired tokens, permissions)
+    # 409: Conflict errors
+    if response.status_code != 404:
         return None
 
     parent = ctx._find_parent(case_id=case.id)
@@ -491,7 +497,11 @@ def ignored_auth(ctx: CheckContext, response: Response, case: Case) -> bool | No
     """Check if an operation declares authentication as a requirement but does not actually enforce it."""
     from .schemas import BaseOpenAPISchema
 
-    if not isinstance(case.operation.schema, BaseOpenAPISchema) or is_unexpected_http_status_case(case):
+    if (
+        not isinstance(case.operation.schema, BaseOpenAPISchema)
+        or is_unexpected_http_status_case(case)
+        or _has_optional_auth(case.operation)
+    ):
         return True
     security_parameters = _get_security_parameters(case.operation)
     # Authentication is required for this API operation and response is successful
@@ -513,6 +523,8 @@ def ignored_auth(ctx: CheckContext, response: Response, case: Case) -> bool | No
                     _remove_auth_from_container(container, security_parameters, location=location)
                     kwargs[container_name] = container
             kwargs.pop("session", None)
+            if case.operation.app is not None:
+                kwargs.setdefault("app", case.operation.app)
             ctx._record_case(parent_id=case.id, case=no_auth_case)
             no_auth_response = case.operation.schema.transport.send(no_auth_case, **kwargs)
             ctx._record_response(case_id=no_auth_case.id, response=no_auth_response)
@@ -577,6 +589,13 @@ def _get_security_parameters(operation: APIOperation) -> list[SecurityParameter]
     ]
 
 
+def _has_optional_auth(operation: APIOperation) -> bool:
+    from .schemas import BaseOpenAPISchema
+
+    schema = cast(BaseOpenAPISchema, operation.schema)
+    return schema.security.has_optional_auth(schema.raw_schema, operation)
+
+
 def _contains_auth(
     ctx: CheckContext, case: Case, response: Response, security_parameters: list[SecurityParameter]
 ) -> AuthKind | None:
