@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import itertools
+import string
 from collections import defaultdict
 from contextlib import ExitStack, contextmanager, suppress
 from dataclasses import dataclass, field
@@ -29,7 +30,7 @@ from requests.exceptions import InvalidHeader
 from requests.structures import CaseInsensitiveDict
 from requests.utils import check_header_validity
 
-from schemathesis.core import NOT_SET, NotSet, Specification, deserialization, media_types
+from schemathesis.core import INJECTED_PATH_PARAMETER_KEY, NOT_SET, NotSet, Specification, deserialization, media_types
 from schemathesis.core.compat import RefResolutionError
 from schemathesis.core.errors import InternalError, InvalidSchema, LoaderError, LoaderErrorKind, OperationNotFound
 from schemathesis.core.failures import Failure, FailureGroup, MalformedJson
@@ -47,7 +48,6 @@ from ...generation import GenerationMode
 from ...hooks import HookContext, HookDispatcher
 from ...schemas import APIOperation, APIOperationMap, ApiStatistic, BaseSchema, OperationDefinition
 from . import serialization
-from ._cache import OperationCache
 from ._hypothesis import openapi_cases
 from .converter import to_json_schema, to_json_schema_recursive
 from .definitions import OPENAPI_30_VALIDATOR, OPENAPI_31_VALIDATOR, SWAGGER_20_VALIDATOR
@@ -90,18 +90,29 @@ def check_header(parameter: dict[str, Any]) -> None:
         raise InvalidSchema(f"Invalid header name: {name}")
 
 
+def get_template_fields(template: str) -> set[str]:
+    """Extract named placeholders from a string template."""
+    try:
+        parameters = {name for _, name, _, _ in string.Formatter().parse(template) if name is not None}
+        # Check for malformed params to avoid injecting them - they will be checked later on in the workflow
+        template.format(**dict.fromkeys(parameters, ""))
+        return parameters
+    except (ValueError, IndexError):
+        return set()
+
+
 @dataclass(eq=False, repr=False)
 class BaseOpenAPISchema(BaseSchema):
     nullable_name: ClassVar[str] = ""
     links_field: ClassVar[str] = ""
     header_required_field: ClassVar[str] = ""
     security: ClassVar[BaseSecurityProcessor] = None  # type: ignore
-    _operation_cache: OperationCache = field(default_factory=OperationCache)
     _inline_reference_cache: dict[str, Any] = field(default_factory=dict)
     # Inline references cache can be populated from multiple threads, therefore we need some synchronisation to avoid
     # excessive resolving
     _inline_reference_cache_lock: RLock = field(default_factory=RLock)
     component_locations: ClassVar[tuple[tuple[str, ...], ...]] = ()
+    _path_parameter_template: ClassVar[dict[str, Any]] = None  # type: ignore
 
     @property
     def specification(self) -> Specification:
@@ -115,17 +126,12 @@ class BaseOpenAPISchema(BaseSchema):
         return iter(self.raw_schema.get("paths", {}))
 
     def _get_operation_map(self, path: str) -> APIOperationMap:
-        cache = self._operation_cache
-        map = cache.get_map(path)
-        if map is not None:
-            return map
         path_item = self.raw_schema.get("paths", {})[path]
         with in_scope(self.resolver, self.location or ""):
             scope, path_item = self._resolve_path_item(path_item)
         self.dispatch_hook("before_process_path", HookContext(), path, path_item)
         map = APIOperationMap(self, {})
         map._data = MethodMap(map, scope, path, CaseInsensitiveDict(path_item))
-        cache.insert_map(path, map)
         return map
 
     def find_operation_by_label(self, label: str) -> APIOperation | None:
@@ -136,7 +142,7 @@ class BaseOpenAPISchema(BaseSchema):
         matches = get_close_matches(item, list(self))
         self._on_missing_operation(item, exc, matches)
 
-    def _on_missing_operation(self, item: str, exc: KeyError, matches: list[str]) -> NoReturn:
+    def _on_missing_operation(self, item: str, exc: KeyError | None, matches: list[str]) -> NoReturn:
         message = f"`{item}` not found"
         if matches:
             message += f". Did you mean `{matches[0]}`?"
@@ -195,7 +201,7 @@ class BaseOpenAPISchema(BaseSchema):
                 self.resolver.push_scope(scope)
                 try:
                     for method, definition in path_item.items():
-                        if method not in HTTP_METHODS:
+                        if method not in HTTP_METHODS or not definition:
                             continue
                         statistic.operations.total += 1
                         is_selected = not should_skip(path, method, definition)
@@ -239,7 +245,7 @@ class BaseOpenAPISchema(BaseSchema):
 
         return statistic
 
-    def _operation_iter(self) -> Generator[dict[str, Any], None, None]:
+    def _operation_iter(self) -> Iterator[tuple[str, str, dict[str, Any]]]:
         try:
             paths = self.raw_schema["paths"]
         except KeyError:
@@ -250,13 +256,11 @@ class BaseOpenAPISchema(BaseSchema):
             try:
                 if "$ref" in path_item:
                     _, path_item = resolve(path_item["$ref"])
-                # Straightforward iteration is faster than converting to a set & calculating length.
                 for method, definition in path_item.items():
                     if should_skip(path, method, definition):
                         continue
-                    yield definition
+                    yield (method, path, definition)
             except SCHEMA_PARSING_ERRORS:
-                # Ignore errors
                 continue
 
     def _resolve_until_no_references(self, value: dict[str, Any]) -> dict[str, Any]:
@@ -400,7 +404,6 @@ class BaseOpenAPISchema(BaseSchema):
         resolved: dict[str, Any],
         scope: str,
     ) -> APIOperation:
-        """Create JSON schemas for the query, body, etc from Swagger parameters definitions."""
         __tracebackhide__ = True
         base_url = self.get_base_url()
         operation: APIOperation[OpenAPIParameter] = APIOperation(
@@ -413,6 +416,14 @@ class BaseOpenAPISchema(BaseSchema):
         )
         for parameter in parameters:
             operation.add_parameter(parameter)
+        # Inject unconstrained path parameters if any is missing
+        missing_parameter_names = get_template_fields(operation.path) - {
+            parameter.name for parameter in operation.path_parameters
+        }
+        for name in missing_parameter_names:
+            definition = {"name": name, INJECTED_PATH_PARAMETER_KEY: True, **deepclone(self._path_parameter_template)}
+            for parameter in self.collect_parameters([definition], resolved):
+                operation.add_parameter(parameter)
         config = self.config.generation_for(operation=operation)
         if config.with_security_parameters:
             self.security.process_definitions(self.raw_schema, operation, self.resolver)
@@ -443,31 +454,6 @@ class BaseOpenAPISchema(BaseSchema):
 
     def get_operation_by_id(self, operation_id: str) -> APIOperation:
         """Get an `APIOperation` instance by its `operationId`."""
-        cache = self._operation_cache
-        cached = cache.get_operation_by_id(operation_id)
-        if cached is not None:
-            return cached
-        # Operation has not been accessed yet, need to populate the cache
-        if not cache.has_ids_to_definitions:
-            self._populate_operation_id_cache(cache)
-        try:
-            entry = cache.get_definition_by_id(operation_id)
-        except KeyError as exc:
-            matches = get_close_matches(operation_id, cache.known_operation_ids)
-            self._on_missing_operation(operation_id, exc, matches)
-        # It could've been already accessed in a different place
-        traversal_key = (entry.scope, entry.path, entry.method)
-        instance = cache.get_operation_by_traversal_key(traversal_key)
-        if instance is not None:
-            return instance
-        resolved = self._resolve_operation(entry.operation)
-        parameters = self._collect_operation_parameters(entry.path_item, resolved)
-        initialized = self.make_operation(entry.path, entry.method, parameters, entry.operation, resolved, entry.scope)
-        cache.insert_operation(initialized, traversal_key=traversal_key, operation_id=operation_id)
-        return initialized
-
-    def _populate_operation_id_cache(self, cache: OperationCache) -> None:
-        """Collect all operation IDs from the schema."""
         resolve = self.resolver.resolve
         default_scope = self.resolver.resolution_scope
         for path, path_item in self.raw_schema.get("paths", {}).items():
@@ -477,44 +463,29 @@ class BaseOpenAPISchema(BaseSchema):
                 scope, path_item = resolve(path_item["$ref"])
             else:
                 scope = default_scope
-            for key, entry in path_item.items():
-                if key not in HTTP_METHODS:
+            for method, operation in path_item.items():
+                if method not in HTTP_METHODS:
                     continue
-                if "operationId" in entry:
-                    cache.insert_definition_by_id(
-                        entry["operationId"],
-                        path=path,
-                        method=key,
-                        scope=scope,
-                        path_item=path_item,
-                        operation=entry,
-                    )
+                if "operationId" in operation and operation["operationId"] == operation_id:
+                    resolved = self._resolve_operation(operation)
+                    parameters = self._collect_operation_parameters(path_item, resolved)
+                    return self.make_operation(path, method, parameters, operation, resolved, scope)
+        self._on_missing_operation(operation_id, None, [])
 
     def get_operation_by_reference(self, reference: str) -> APIOperation:
         """Get local or external `APIOperation` instance by reference.
 
         Reference example: #/paths/~1users~1{user_id}/patch
         """
-        cache = self._operation_cache
-        cached = cache.get_operation_by_reference(reference)
-        if cached is not None:
-            return cached
         scope, operation = self.resolver.resolve(reference)
         path, method = scope.rsplit("/", maxsplit=2)[-2:]
         path = path.replace("~1", "/").replace("~0", "~")
-        # Check the traversal cache as it could've been populated in other places
-        traversal_key = (self.resolver.resolution_scope, path, method)
-        cached = cache.get_operation_by_traversal_key(traversal_key)
-        if cached is not None:
-            return cached
         with in_scope(self.resolver, scope):
             resolved = self._resolve_operation(operation)
         parent_ref, _ = reference.rsplit("/", maxsplit=1)
         _, path_item = self.resolver.resolve(parent_ref)
         parameters = self._collect_operation_parameters(path_item, resolved)
-        initialized = self.make_operation(path, method, parameters, operation, resolved, scope)
-        cache.insert_operation(initialized, traversal_key=traversal_key, reference=reference)
-        return initialized
+        return self.make_operation(path, method, parameters, operation, resolved, scope)
 
     def get_case_strategy(
         self,
@@ -646,6 +617,10 @@ class BaseOpenAPISchema(BaseSchema):
                     # Use a recent JSON Schema format checker to get most of formats checked for older drafts as well
                     format_checker=jsonschema.Draft202012Validator.FORMAT_CHECKER,
                 )
+            except jsonschema.SchemaError as exc:
+                raise InvalidSchema.from_jsonschema_error(
+                    exc, path=operation.path, method=operation.method, config=self.config.output
+                ) from exc
             except jsonschema.ValidationError as exc:
                 failures.append(
                     JsonSchemaError.from_exception(
@@ -847,22 +822,15 @@ class MethodMap(Mapping):
         method = method.lower()
         operation = self._path_item[method]
         schema = cast(BaseOpenAPISchema, self._parent._schema)
-        cache = schema._operation_cache
         path = self._path
         scope = self._scope
-        traversal_key = (scope, path, method)
-        cached = cache.get_operation_by_traversal_key(traversal_key)
-        if cached is not None:
-            return cached
         schema.resolver.push_scope(scope)
         try:
             resolved = schema._resolve_operation(operation)
         finally:
             schema.resolver.pop_scope()
         parameters = schema._collect_operation_parameters(self._path_item, resolved)
-        initialized = schema.make_operation(path, method, parameters, operation, resolved, scope)
-        cache.insert_operation(initialized, traversal_key=traversal_key, operation_id=resolved.get("operationId"))
-        return initialized
+        return schema.make_operation(path, method, parameters, operation, resolved, scope)
 
     def __getitem__(self, item: str) -> APIOperation:
         try:
@@ -887,6 +855,7 @@ class SwaggerV20(BaseOpenAPISchema):
     security = SwaggerSecurityProcessor()
     component_locations: ClassVar[tuple[tuple[str, ...], ...]] = (("definitions",),)
     links_field = "x-links"
+    _path_parameter_template = {"in": "path", "required": True, "type": "string"}
 
     @property
     def specification(self) -> Specification:
@@ -1055,6 +1024,7 @@ class OpenApi30(SwaggerV20):
     security = OpenAPISecurityProcessor()
     component_locations = (("components", "schemas"),)
     links_field = "links"
+    _path_parameter_template = {"in": "path", "required": True, "schema": {"type": "string"}}
 
     @property
     def specification(self) -> Specification:
