@@ -1,7 +1,10 @@
-import json
-from typing import Any, Callable, Dict, Generator, List, Optional, Tuple, Union
+from __future__ import annotations
 
-from ...utils import compose
+import json
+from typing import Any, Callable, Dict, Generator, List
+
+from schemathesis.schemas import APIOperation
+from schemathesis.specs.openapi.constants import LOCATION_TO_CONTAINER
 
 Generated = Dict[str, Any]
 Definition = Dict[str, Any]
@@ -9,21 +12,38 @@ DefinitionList = List[Definition]
 MapFunction = Callable[[Generated], Generated]
 
 
+def get_serializers_for_operation(operation: APIOperation) -> dict[str, Callable]:
+    serializers = {}
+    for location, container in LOCATION_TO_CONTAINER.items():
+        serializer = operation.get_parameter_serializer(location)
+        if serializer is not None:
+            serializers[container] = serializer
+    return serializers
+
+
 def make_serializer(
-    func: Callable[[DefinitionList], Generator[Optional[Callable], None, None]]
-) -> Callable[[DefinitionList], Optional[Callable]]:
+    func: Callable[[DefinitionList], Generator[Callable | None, None, None]],
+) -> Callable[[DefinitionList], Callable | None]:
     """A maker function to avoid code duplication."""
 
-    def _wrapper(definitions: DefinitionList) -> Optional[Callable]:
-        conversions = list(func(definitions))
-        if conversions:
-            return compose(*[conv for conv in conversions if conv is not None])
-        return None
+    def _wrapper(definitions: DefinitionList) -> Callable | None:
+        functions = list(func(definitions))
+        if not functions:
+            return None
+
+        def composed(x: Any) -> Any:
+            result = x
+            for func in reversed(functions):
+                if func is not None:
+                    result = func(result)
+            return result
+
+        return composed
 
     return _wrapper
 
 
-def _serialize_openapi3(definitions: DefinitionList) -> Generator[Optional[Callable], None, None]:
+def _serialize_openapi3(definitions: DefinitionList) -> Generator[Callable | None, None, None]:
     """Different collection styles for Open API 3.0."""
     for definition in definitions:
         name = definition["name"]
@@ -49,9 +69,8 @@ def _serialize_openapi3(definitions: DefinitionList) -> Generator[Optional[Calla
 
 
 def _serialize_path_openapi3(
-    name: str, type_: str, style: Optional[str], explode: Optional[bool]
-) -> Generator[Optional[Callable], None, None]:
-    # pylint: disable=too-many-branches
+    name: str, type_: str, style: str | None, explode: bool | None
+) -> Generator[Callable | None, None, None]:
     if style == "simple":
         if type_ == "object":
             if explode is False:
@@ -77,8 +96,8 @@ def _serialize_path_openapi3(
 
 
 def _serialize_query_openapi3(
-    name: str, type_: str, style: Optional[str], explode: Optional[bool]
-) -> Generator[Optional[Callable], None, None]:
+    name: str, type_: str, style: str | None, explode: bool | None
+) -> Generator[Callable | None, None, None]:
     if type_ == "object":
         if style == "deepObject":
             yield deep_object(name)
@@ -96,9 +115,7 @@ def _serialize_query_openapi3(
             yield delimited(name, delimiter=",")
 
 
-def _serialize_header_openapi3(
-    name: str, type_: str, explode: Optional[bool]
-) -> Generator[Optional[Callable], None, None]:
+def _serialize_header_openapi3(name: str, type_: str, explode: bool | None) -> Generator[Callable | None, None, None]:
     # Headers should be coerced to a string so we can check it for validity later
     yield to_string(name)
     # Header parameters always use the "simple" style, that is, comma-separated values
@@ -111,9 +128,7 @@ def _serialize_header_openapi3(
             yield delimited_object(name)
 
 
-def _serialize_cookie_openapi3(
-    name: str, type_: str, explode: Optional[bool]
-) -> Generator[Optional[Callable], None, None]:
+def _serialize_cookie_openapi3(name: str, type_: str, explode: bool | None) -> Generator[Callable | None, None, None]:
     # Cookies should be coerced to a string so we can check it for validity later
     yield to_string(name)
     # Cookie parameters always use the "form" style
@@ -130,7 +145,7 @@ def _serialize_cookie_openapi3(
             yield comma_delimited_object(name)
 
 
-def _serialize_swagger2(definitions: DefinitionList) -> Generator[Optional[Callable], None, None]:
+def _serialize_swagger2(definitions: DefinitionList) -> Generator[Callable | None, None, None]:
     """Different collection formats for Open API 2.0."""
     for definition in definitions:
         name = definition["name"]
@@ -166,11 +181,11 @@ def conversion(func: Callable[..., None]) -> Callable:
     return _wrapper
 
 
-def make_delimited(data: Optional[Dict[str, Any]], delimiter: str = ",") -> str:
+def make_delimited(data: dict[str, Any] | None, delimiter: str = ",") -> str:
     return delimiter.join(f"{key}={value}" for key, value in force_dict(data or {}).items())
 
 
-def force_iterable(value: Any) -> Union[List, Tuple]:
+def force_iterable(value: Any) -> list | tuple:
     """Converts the value to a list or a tuple.
 
     Only relevant for negative test scenarios where the original types might be changed.
@@ -180,7 +195,7 @@ def force_iterable(value: Any) -> Union[List, Tuple]:
     return [value]
 
 
-def force_dict(value: Any) -> Dict:
+def force_dict(value: Any) -> dict:
     """Converts the value to a dictionary.
 
     Only relevant for negative test scenarios where the original types might be changed.
@@ -248,7 +263,7 @@ def label_primitive(item: Generated, name: str) -> None:
 
 
 @conversion
-def label_array(item: Generated, name: str, explode: Optional[bool]) -> None:
+def label_array(item: Generated, name: str, explode: bool | None) -> None:
     """Serialize an array with the `label` style.
 
     Explode=True
@@ -271,7 +286,7 @@ def label_array(item: Generated, name: str, explode: Optional[bool]) -> None:
 
 
 @conversion
-def label_object(item: Generated, name: str, explode: Optional[bool]) -> None:
+def label_object(item: Generated, name: str, explode: bool | None) -> None:
     """Serialize an object with the `label` style.
 
     Explode=True
@@ -307,7 +322,7 @@ def matrix_primitive(item: Generated, name: str) -> None:
 
 
 @conversion
-def matrix_array(item: Generated, name: str, explode: Optional[bool]) -> None:
+def matrix_array(item: Generated, name: str, explode: bool | None) -> None:
     """Serialize an array with the `matrix` style.
 
     Explode=True
@@ -329,7 +344,7 @@ def matrix_array(item: Generated, name: str, explode: Optional[bool]) -> None:
 
 
 @conversion
-def matrix_object(item: Generated, name: str, explode: Optional[bool]) -> None:
+def matrix_object(item: Generated, name: str, explode: bool | None) -> None:
     """Serialize an object with the `matrix` style.
 
     Explode=True
