@@ -13,6 +13,7 @@ import trustme
 import urllib3.exceptions
 import yaml
 from _pytest.main import ExitCode
+from flask import Flask, jsonify, redirect, url_for
 
 from schemathesis.schemas import APIOperation
 from schemathesis.specs.openapi import unregister_string_format
@@ -130,6 +131,7 @@ def test_schema_not_available(cli, workers, snapshot_cli):
 
 @pytest.mark.openapi_version("3.0")
 @pytest.mark.operations("success")
+@pytest.mark.snapshot_suffix(platform.python_implementation().lower())
 def test_empty_schema_file(testdir, cli, snapshot_cli):
     # When the schema file is empty
     filename = testdir.makefile(".json", schema="")
@@ -289,6 +291,7 @@ def test_status_code_conformance(cli, schema_url, workers, snapshot_cli):
 
 
 @pytest.mark.operations("headers")
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="aiohttp crashes on PyPy")
 def test_headers_conformance_valid(cli, schema_url):
     result = cli.run(schema_url, "-c", "response_headers_conformance", "-H", "X-Custom-Header: 42")
     assert result.exit_code == ExitCode.OK, result.stdout
@@ -557,6 +560,78 @@ async def test_multiple_files_schema(ctx, openapi_2_app, cli, hypothesis_max_exa
     assert isinstance(payload["photoUrls"], list)
 
 
+@pytest.mark.parametrize("required", [True, False])
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {},
+        {"required": []},
+        {"required": ["region"]},
+    ],
+    ids=["no-required", "not-in-required", "in-required"],
+)
+def test_required_as_boolean(ctx, cli, snapshot_cli, openapi3_base_url, required, kwargs):
+    # Happens in the wild, even though it is incorrect
+    schema_path = ctx.openapi.write_schema(
+        {
+            "/success": {
+                "post": {
+                    "requestBody": {
+                        "content": {
+                            "application/json": {
+                                "schema": {
+                                    "properties": {
+                                        "region": {
+                                            "required": required,
+                                            "type": "string",
+                                        },
+                                    },
+                                    "type": "object",
+                                    **kwargs,
+                                }
+                            }
+                        },
+                        "required": True,
+                    },
+                    "responses": {"200": {"description": "OK"}},
+                }
+            }
+        }
+    )
+    assert (
+        cli.run(str(schema_path), f"--url={openapi3_base_url}", "-c not_a_server_error", "--max-examples=5")
+        == snapshot_cli
+    )
+
+
+def test_invalid_response_definition(ctx, cli, snapshot_cli, openapi3_base_url):
+    schema_path = ctx.openapi.write_schema(
+        {
+            "/success": {
+                "get": {
+                    "responses": {
+                        "default": {
+                            "description": "text",
+                            "content": {
+                                "application/json": {
+                                    "schema": {
+                                        # Seen in real-life schema
+                                        "properties": "ABC",
+                                    }
+                                }
+                            },
+                        }
+                    }
+                }
+            }
+        }
+    )
+    assert (
+        cli.run(str(schema_path), f"--url={openapi3_base_url}", "-c response_schema_conformance", "--max-examples=1")
+        == snapshot_cli
+    )
+
+
 def test_no_useless_traceback(ctx, cli, snapshot_cli, openapi3_base_url):
     schema_path = ctx.openapi.write_schema(
         {
@@ -1015,6 +1090,7 @@ def test_response_schema_conformance_deduplication(cli, schema_url, snapshot_cli
 
 @pytest.mark.openapi_version("3.0")
 @pytest.mark.operations("malformed_json")
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy behaves differently")
 def test_malformed_json_deduplication(cli, schema_url, snapshot_cli):
     # See GH-1518
     # When responses are not JSON as expected and their content differ each time
@@ -1231,6 +1307,12 @@ def test_rate_limit(cli, schema_url):
     assert cli.run(schema_url, "--rate-limit=1/s").exit_code == ExitCode.OK
 
 
+@pytest.mark.openapi_version("3.0")
+@pytest.mark.operations("failure")
+def test_invalid_tls_verify(cli, schema_url, snapshot_cli):
+    assert cli.run(schema_url.replace("http", "https"), "--tls-verify=falst") == snapshot_cli
+
+
 @pytest.mark.parametrize("version", ["3.0.2", "3.1.0"])
 def test_invalid_schema_with_disabled_validation(
     ctx, cli, openapi_3_schema_with_invalid_security, version, snapshot_cli, openapi3_base_url
@@ -1584,6 +1666,63 @@ def test_parameter_overrides(cli, schema_url, verify_overrides):
     assert result.exit_code == ExitCode.OK, result.stdout
 
 
+@pytest.mark.parametrize(
+    ["args", "config"],
+    (
+        (
+            ("--max-redirects=5",),
+            {},
+        ),
+        (
+            (),
+            {"max-redirects": 5},
+        ),
+    ),
+)
+def test_max_redirects(cli, app_runner, snapshot_cli, args, config):
+    raw_schema = {
+        "openapi": "3.0.0",
+        "info": {"title": "Redirect Test", "version": "1.0.0"},
+        "paths": {
+            "/redirect": {
+                "get": {
+                    "responses": {
+                        "302": {"description": "Redirect"},
+                        "200": {
+                            "description": "Success",
+                        },
+                    },
+                }
+            }
+        },
+    }
+
+    app = Flask(__name__)
+
+    @app.route("/openapi.json")
+    def schema():
+        return jsonify(raw_schema)
+
+    @app.route("/redirect", methods=["GET"])
+    def redirect_endpoint():
+        # Infinite loop
+        return redirect(url_for("redirect_endpoint"), code=302)
+
+    port = app_runner.run_flask_app(app)
+
+    assert (
+        cli.main(
+            "run",
+            "--phases=fuzzing",
+            "--max-examples=1",
+            f"http://127.0.0.1:{port}/openapi.json",
+            *args,
+            config=config,
+        )
+        == snapshot_cli
+    )
+
+
 @pytest.fixture
 def no_null_bytes(ctx):
     with ctx.check(
@@ -1730,6 +1869,7 @@ def always_fails(ctx, response, case):
 
 
 @pytest.mark.skipif(platform.system() == "Windows", reason="Requires extra setup on Windows")
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy behaves differently")
 def test_app_crash(subprocess_runner, cli, snapshot_cli):
     app = """
 import os
@@ -1763,6 +1903,7 @@ if __name__ == "__main__":
 
 
 @pytest.mark.skipif(platform.system() == "Windows", reason="Requires extra setup on Windows")
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy behaves differently")
 def test_partial_response(subprocess_runner, cli, snapshot_cli):
     app = """
 import os
@@ -1804,6 +1945,7 @@ if __name__ == "__main__":
 
 @pytest.mark.skipif(platform.system() == "Windows", reason="Requires extra setup on Windows")
 @pytest.mark.snapshot(replace_phase_statistic=True)
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy behaves differently")
 def test_stateful_crash(subprocess_runner, cli, snapshot_cli):
     app = """
 import os
