@@ -117,6 +117,7 @@ def pytest_generate_tests(metafunc):
 def pytest_configure(config):
     config.addinivalue_line("markers", "operations(*names): Add only specified API operations to the test application.")
     config.addinivalue_line("markers", "snapshot(**kwargs): Configure snapshot tests.")
+    config.addinivalue_line("markers", "snapshot_suffix(suffix): Append a suffix to the snapshot file name.")
     config.addinivalue_line("markers", "hypothesis_nested: Mark tests with nested Hypothesis tests.")
     config.addinivalue_line(
         "markers",
@@ -425,16 +426,15 @@ class CliSnapshotConfig:
             data = re.sub(r"Seed: \d+", "Seed: 42", data)
         if self.replace_reproduce_with:
             lines = []
-            replace_next_non_empty = False
+            seen = False
             for line in data.splitlines():
-                if replace_next_non_empty and line:
-                    lines.append("    <PLACEHOLDER>")
+                if "curl" in line:
+                    if not seen:
+                        lines.append("    <PLACEHOLDER>")
+                        seen = True
                 else:
+                    seen = False
                     lines.append(line)
-                if line.startswith("Reproduce with:"):
-                    replace_next_non_empty = True
-                elif line:
-                    replace_next_non_empty = False
             data = "\n".join(lines) + "\n"
         lines = []
         for line in data.splitlines():
@@ -538,6 +538,7 @@ EXAMPLE_UUID = "e32ab85ed4634c38a320eb0b22460da9"
 @pytest.fixture
 def snapshot_cli(request, snapshot):
     config = CliSnapshotConfig.from_request(request)
+    snapshot_suffix = request.node.get_closest_marker("snapshot_suffix")
 
     class CliSnapshotExtension(SingleFileSnapshotExtension):
         _write_mode = WriteMode.TEXT
@@ -565,6 +566,14 @@ def snapshot_cli(request, snapshot):
                 serialized += f"\n---\nStdout:\n{stdout}"
             return config.serialize(serialized).replace("\r\n", "\n").replace("\r", "\n")
 
+        @classmethod
+        def get_snapshot_name(cls, *, test_location, index=0) -> str:
+            base_name = super().get_snapshot_name(test_location=test_location, index=index)
+            if snapshot_suffix is not None:
+                suffix = str(snapshot_suffix.args[0])
+                return f"{base_name}.{suffix}"
+            return base_name
+
     class SnapshotAssertion(snapshot.__class__):
         def rebuild(self):
             return self.use_extension(extension_class=CliSnapshotExtension)
