@@ -48,10 +48,10 @@ def assert_conform(values: list, schema: dict):
 
 
 def assert_not_conform(values: list, schema: dict):
+    if isinstance(schema, dict) and schema.get("format") == "unknown":
+        # Can't validate the format
+        return
     for entry in values:
-        if schema.get("format") == "unknown":
-            # Can't validate the format
-            continue
         try:
             jsonschema.validate(
                 entry,
@@ -59,7 +59,7 @@ def assert_not_conform(values: list, schema: dict):
                 cls=jsonschema.Draft7Validator,
                 format_checker=jsonschema.Draft202012Validator.FORMAT_CHECKER,
             )
-            raise ValueError(f"Value {entry} conforms to {schema}")
+            raise AssertionError(f"Value {entry} conforms to {schema}")
         except (jsonschema.ValidationError, ValueError):
             pass
 
@@ -99,11 +99,16 @@ def nctx():
 @pytest.mark.parametrize(
     ("schema", "expected"),
     [
+        (True, [None, True, False, "", 0, [None, None], {}]),
+        ({}, [None, True, False, "", 0, [None, None], {}]),
+        (False, []),
         ({"type": "null"}, [None]),
         ({"type": "boolean"}, [True, False]),
         ({"type": ["boolean", "null"]}, [True, False, None]),
         ({"enum": [1, 2]}, [1, 2]),
         ({"const": 42}, [42]),
+        ({"not": {}}, []),
+        ({"not": {"type": "null"}}, [0, "false", "", ["null", "null"]]),
     ],
 )
 def test_positive_primitive_schemas(pctx, schema, expected):
@@ -126,6 +131,9 @@ class AnyNumber:
 @pytest.mark.parametrize(
     ("schema", "expected"),
     [
+        (False, [None, True, False, "", 0, [None, None], {}]),
+        (True, []),
+        ({}, []),
         ({"type": "null"}, [0, "false", "", ["null", "null"]]),
         ({"type": "boolean"}, [0, "null", "", ["null", "null"]]),
         ({"type": ["boolean", "null"]}, [0, "", ["null", "null"]]),
@@ -142,6 +150,8 @@ class AnyNumber:
         ({"exclusiveMinimum": 5}, [5]),
         ({"exclusiveMaximum": 5}, [5]),
         ({"required": ["a"]}, [{}]),
+        ({"not": {}}, [None, True, False, "", 0, [None, None], {}]),
+        ({"not": {"type": "null"}}, [None]),
     ],
 )
 def test_negative_primitive_schemas(nctx, schema, expected):
@@ -281,6 +291,23 @@ def test_positive_number(ctx, schema, multiple_of, values, with_multiple_of):
                 {"foo": ANY},
                 {"foo": ANY},
                 {"foo": ANY},
+                {"foo": ANY},
+            ],
+        ),
+        (
+            {
+                "type": "object",
+                "properties": {"foo": {}},
+                "required": ["foo"],
+            },
+            [
+                {"foo": ANY},
+                {"foo": ANY},
+                {"foo": ANY},
+                {"foo": ANY},
+                {"foo": ANY},
+                {"foo": ANY},
+                {"foo": ANY},
             ],
         ),
         (
@@ -1048,7 +1075,7 @@ def test_positive_pattern(pctx):
     covered = cover_schema(pctx, schema)
     assert covered == ["0000-0000", "00-0000", "00-00000", "0000-000000000000000", "000-000000000000000"]
     assert_unique(covered)
-    assert_not_conform(covered, schema)
+    assert_conform(covered, schema)
 
 
 def test_negative_pattern_with_incompatible_length(nctx):
@@ -1099,7 +1126,11 @@ def test_negative_pattern_with_incompatible_length(nctx):
                     {"type": "string", "maxLength": 5},
                 ],
             },
-            [4, AnyNumber(), AnyNumber(), "000000"],
+            (
+                [4, AnyNumber(), AnyNumber()],
+                [4, AnyNumber()],
+                [4],
+            ),
         ),
         (
             {
@@ -1116,7 +1147,7 @@ def test_negative_pattern_with_incompatible_length(nctx):
                     },
                 ]
             },
-            [ANY, "00000000000", AnyNumber(), AnyNumber()],
+            ["00000000000", AnyNumber(), AnyNumber()],
         ),
         (
             {
@@ -1137,7 +1168,63 @@ def test_negative_combinators(nctx, schema, expected):
             assert_not_conform(covered, schema)
             break
     else:
-        pytest.fail("Expected value didn't match")
+        pytest.fail(f"Expected value didn't match\nGot: {covered!r}\nExpected: {expected!r}")
+
+
+@pytest.mark.parametrize(
+    ["schema", "expected"],
+    [
+        (
+            {
+                "anyOf": [
+                    {"type": "number"},
+                    {"type": "null"},
+                ]
+            },
+            [
+                False,
+                "",
+                [
+                    None,
+                    None,
+                ],
+                {},
+            ],
+        ),
+        (
+            {
+                "oneOf": [
+                    {"type": "number"},
+                    {"type": "integer"},
+                    {"type": "null"},
+                ]
+            },
+            [
+                False,
+                "",
+                [
+                    None,
+                    None,
+                ],
+                {},
+                # Matching both, "number" and "integer", hence invalid
+                0,
+            ],
+        ),
+    ],
+)
+def test_negative_one_of(schema, expected):
+    # See GH-2975
+    nctx = CoverageContext(
+        location="body",
+        generation_modes=[GenerationMode.NEGATIVE],
+        is_required=True,
+        custom_formats=get_default_format_strategies(),
+        validator_cls=jsonschema.validators.Draft202012Validator,
+    )
+    covered = cover_schema(nctx, schema)
+    assert_not_conform(covered, schema)
+    assert covered == expected
 
 
 @pytest.mark.parametrize(
