@@ -3,7 +3,6 @@ import platform
 import pytest
 
 from schemathesis.core.errors import RECURSIVE_REFERENCE_ERROR_MESSAGE
-from schemathesis.generation.hypothesis import DEFAULT_DEADLINE
 from schemathesis.generation.modes import GenerationMode
 
 
@@ -154,15 +153,15 @@ def test_b(case, a):
 
 def test_default_hypothesis_deadline(testdir):
     testdir.make_test(
-        f"""
+        """
 @schema.parametrize()
 def test_a(case):
-    assert settings().deadline.total_seconds() == {DEFAULT_DEADLINE} / 1000
+    assert settings().deadline is None
 
 @schema.parametrize()
 @settings(max_examples=5)
 def test_b(case):
-    assert settings().deadline.total_seconds() == {DEFAULT_DEADLINE} / 1000
+    assert settings().deadline is None
 
 @schema.parametrize()
 @settings(max_examples=5, deadline=100)
@@ -175,7 +174,7 @@ def test_d():
     )
     # When there is a test with Pytest
     result = testdir.runpytest()
-    # Then it should use the global Schemathesis deadline for Hypothesis (DEFAULT_DEADLINE value)
+    # Then it should use the global Schemathesis deadline for Hypothesis (None)
     result.assert_outcomes(passed=4)
 
 
@@ -672,6 +671,7 @@ config = schemathesis.Config.from_dict({{
     }}
 }})
 schema = schemathesis.openapi.from_url('{openapi3_schema_url}', config=config)
+schema.config.generation.update(modes=[GenerationMode.POSITIVE])
 
 @schema.include(name="GET /basic").parametrize()
 def test(case):
@@ -910,6 +910,21 @@ def test(case):
     assert "while generating" not in result.stdout.str()
 
 
+@pytest.mark.operations("missing_path_parameter")
+def test_missing_path_parameter(testdir, openapi3_schema_url):
+    testdir.make_test(
+        f"""
+schema = schemathesis.openapi.from_url('{openapi3_schema_url}')
+
+@schema.parametrize()
+def test(case):
+    case.call_and_validate()
+"""
+    )
+    result = testdir.runpytest()
+    result.assert_outcomes(failed=1)
+
+
 @pytest.mark.operations("failure")
 def test_disable_checks_via_config(testdir, openapi3_schema_url):
     testdir.make_test(
